%define sslcerts %{_sysconfdir}/ssl/certs
%define admin_trust_dir %{_sysconfdir}/pki/trust

%define commit_date 20170807
%define commit_id 10b278586d2378e25d5cc9463be84c29725aa918
%define short_id %{expand:%%{lua: str='%{commit_id}'; print(str:sub(0, 7))}}

Name: ca-certificates
Version: 2_git%{commit_date}.%{short_id}
Release: 1
License: GPL-2.0-or-later
Summary: Utilities for managing TLS certificate stores
Url: https://github.com/openSUSE/ca-certificates
BuildArch: noarch

Source0: https://github.com/openSUSE/ca-certificates/archive/%{commit_id}.zip

Requires: p11-kit-trust

Recommends: ca-certificates-mozilla


%description
Utilities for managing and synchronizing TLS (SSL) certificate stores across
various libraries and tools which may use different formats or locations to find
their certificate stores.

%prep
%setup -q -n %{name}-%{commit_id}

perl -p -i -e 's|/usr/lib|%{_libdir}|g' update-ca-certificates
perl -p -i -e 's|/etc|%{_sysconfdir}|g' update-ca-certificates
perl -p -i -e 's|/usr/bin/perl|%{_bindir}/perl|g' update-ca-certificates

perl -p -i -e 's|/bin/bash|%{_bindir}/bash|g' *.run
perl -p -i -e 's|/var|%{_localstatedir}|g' *.run
perl -p -i -e 's|trust|%{_bindir}/trust|g' *.run

# make them orderable
mv java.run 50-java.run
mv openssl.run 50-openssl.run


%install
install -D -m 755 update-ca-certificates %{buildroot}%{_bindir}/update-ca-certificates
install -D -m 644 update-ca-certificates.8 %{buildroot}%{_mandir}/man8/update-ca-certificates.8

mkdir -p %{buildroot}%{_sysconfdir}/ca-certificates/update.d
mkdir -p %{buildroot}%{_libdir}/ca-certificates/update.d

install -D -m 755 50-java.run    %{buildroot}%{_libdir}/ca-certificates/update.d/50-java.run
install -D -m 755 50-openssl.run %{buildroot}%{_libdir}/ca-certificates/update.d/50-openssl.run

mkdir -p %{buildroot}/`dirname %{sslcerts}`
ln -s  %{_localstatedir}/lib/ca-certificates/openssl %{buildroot}%{sslcerts}

mkdir -p %{buildroot}%{_localstatedir}/lib/ca-certificates

%pre -p %{_bindir}/bash
# Migrate OpenSSL ssl/certs directory to symlink
if [ "$1" -ne 0 -a -d %{sslcerts} -a ! -L %{sslcerts} ]
then
    # Try to remove the directory if it's empty
    rmdir %{sslcerts} || :
    
    # If we didn't remove the empty directory, copy the pem files
    # to the p11-kit managed trust anchor directory
    if [ -e %{sslcerts} ]
    then
        mkdir -p %{admin_trust_dir}
    
        for cert in %{sslcerts}/*.pem
        do
            # skip any symlinks
            test -f "$cert" -a ! -L "$cert" || continue
            
            # create a p11-kit header that set the label of the certificate
            # to the file name. This ensures that the certificate gets the same
            # name in ssl/certs as before
            base_name="${cert##*/}"
            (
            cat <<EOF
# created by ca-certificates from
# $cert
[p11-kit-object-v1]
class: certificate
label: "${base_name%.pem}"
trusted: true
EOF
            cat $cert
            ) > "%{admin_trust_dir}/$base_name"
        done
    
        mv %{sslcerts} %{sslcerts}.rpmnew
    fi
    ln -s %{_localstatedir}/lib/ca-certificates/openssl %{sslcerts}
    chown -h qsys %{sslcerts}
fi


%post -p %{_bindir}/bash
%{_bindir}/update-ca-certificates || :


%files
%defattr(-, qsys, *none)

%{_bindir}/update-ca-certificates

%{_sysconfdir}/ca-certificates
%{_libdir}/ca-certificates
%dir %{_localstatedir}/lib/ca-certificates

%{sslcerts}

%{_mandir}/man8/update-ca-certificates.8

%changelog
* Thu May 16 2019 Yun Xiang <bjxiangy@cn.ibm.com>
- Fix missing directory /QOpenSys/var/lib/ca-certificates

* Thu May 09 2019 Kevin Adler <kadler@us.ibm.com>
- Change numbering scheme because IBM file server can't handle a + in the name
